revise.path: Adjust the file dir if the lash is not right or the Dropbox...

Description Usage Arguments

View source: R/funcs_for_directories.R

Description

Adjust the file dir if the lash is not right or the Dropbox username is not right

Usage

1

Arguments

dir0

file directory not output for now


liuyanguu/pkgexample documentation built on Dec. 21, 2021, 10:52 a.m.